@@ -50,7 +50,8 @@ def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
     with open(f"{dumpdir}/configmaps.yaml", "w") as f:
         try:
             cm_index = next(
-                i for i, cm in enumerate(_configs["items"])
+                i
+                for i, cm in enumerate(_configs["items"])
                 if cm["metadata"]["name"].startswith("cluster-manager")
             )
             _configs["items"].pop(cm_index)
@@ -58,7 +59,6 @@ def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
         except Exception:
             pass
 
-
     dump_tar = str(dumpdir.resolve()) + ".tar.gz"
     with tarfile.open(dump_tar, "w:gz") as tar:
         tar.add(dumpdir, arcname="")
@@ -84,7 +84,7 @@ def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
     )
     msgs = (
         (
-            "Operaction completed",
+            "Operation completed",
             "Cluster information successfully shared with Indico",
             "green",
         ),
