@@ -43,6 +43,7 @@ def exc(ctx, podname, command="bash"):
     )
     run_cmd(["kubectl", "exec", "-it", pod, command], tty=True)
 
+
 @pod.command("activate-user")
 @click.pass_context
 @click.argument("user_email", required=True)
@@ -53,8 +54,13 @@ def exc(ctx, user_email):
     Args:
         <USER_EMAIL> email of user to activate
     """
-    noct_pod = run_cmd("kubectl get pods | grep noct | head -n 1 | awk '{print $1}'", silent=True)
-    run_cmd(f"kubectl exec -it {noct_pod} -- python3 /noct/alembic/migrations/setup_user_access.py {user_email}")
+    noct_pod = run_cmd(
+        "kubectl get pods | grep noct | head -n 1 | awk '{print $1}'", silent=True
+    )
+    run_cmd(
+        f"kubectl exec -it {noct_pod} -- python3 /noct/alembic/migrations/setup_user_access.py {user_email}"
+    )
+
 
 @pod.command("ls")
 @click.pass_context
