@@ -1,6 +1,6 @@
 import json
-from collections import OrderedDict
 import re
+from collections import OrderedDict
 
 from indico_install.utils.base import run_cmd
 
@@ -155,3 +155,11 @@ def load_from_configmap(configmap_name, data_parser=None):
     except Exception:
         pass
     return
+
+
+def get_cluster_nodes():
+    return run_cmd(
+        "kubectl get nodes --no-headers "
+        "-o custom-columns=NAME:.metadata.name 2>/dev/null",
+        silent=True,
+    ).splitlines()
